@@ -223,7 +223,6 @@ class MainWindow(QtWidgets.QMainWindow):
         self.lastOpenDir = None
 
         self.loadTime = str(datetime.now())
-        self.polygon = False
 
         self.flag_dock = self.flag_widget = None
         self.flag_dock = QtWidgets.QDockWidget(self.tr('Flags'), self)
@@ -235,14 +234,9 @@ class MainWindow(QtWidgets.QMainWindow):
         self.flag_widget.itemChanged.connect(self.setDirty)
 
 
-
-
-        #self.labelList.itemActivated.connect(self.labelSelectionChanged)
         self.labelList.itemSelectionChanged.connect(self.labelSelectionChanged)
         self.labelList.itemDoubleClicked.connect(self.editLabel)
         # Connect to itemChanged to detect checkbox changes.
-        self.labelList.itemChanged.connect(self.labelItemChanged)
-        self.labelList.itemDropped.connect(self.labelOrderChanged)
         self.labelList.setDragDropMode(
            QtWidgets.QAbstractItemView.InternalMove)
         self.labelList.setParent(self)
@@ -253,9 +247,6 @@ class MainWindow(QtWidgets.QMainWindow):
         self.shape_dock.setObjectName('Labels')
         self.shape_dock.setWidget(self.labelList)
 
-
-
-
         self.uniqLabelList = UniqueLabelQListWidget()
         self.uniqLabelList.setToolTip(self.tr(
             "Select label to start annotating for it. "
@@ -1061,10 +1052,8 @@ class MainWindow(QtWidgets.QMainWindow):
             
     def immersiveMode(self):
         if self.actions.hideOthers.isChecked() == True:
-            self.polygon = True
             self.canvas.immersive = True
         elif self.actions.hideOthers.isChecked() == False:
-            self.polygon = False
             self.canvas.immersive = False
     
     def toggleDrawingSensitive(self, drawing=True):
@@ -1494,8 +1483,6 @@ class MainWindow(QtWidgets.QMainWindow):
             self.actions.undoLastPoint.setEnabled(False)
             self.actions.undo.setEnabled(True)
             self.setDirty()
-            # if self.polygon:
-                # self.togglePolygons(1, False)
             if self.actions.hideOthers.isChecked() == True:
                 self.canvas.keyboard_con()
                 self.canvas.immersive_first = True
